@@ -1,5 +1,7 @@
-utils::globalVariables(c("doc_id","uc","uce","segment_size","upos","noSingleChar",
-"token","lemma","freq","chi_square", "cluster", "negative", "positive", "term", "freq_true", "indep", "p_value",".", "segment"))
+utils::globalVariables(c(
+  "doc_id", "uc", "uce", "segment_size", "upos", "noSingleChar",
+  "token", "lemma", "freq", "chi_square", "cluster", "negative", "positive", "term", "freq_true", "indep", "p_value", ".", "segment"
+))
 
 
 #' Segment clustering based on the Reinert method - Simple clustering
@@ -24,16 +26,15 @@ utils::globalVariables(c("doc_id","uc","uce","segment_size","upos","noSingleChar
 #'
 #' @references
 #'
-#' - Reinert M, Une méthode de classification descendante hiérarchique: application à l'analyse lexicale par contexte, Cahiers de l'analyse des données, Volume 8, Numéro 2, 1983. <http://www.numdam.org/item/?id=CAD_1983__8_2_187_0>
+#' - Reinert M, Une méthode de classification descendante hiérarchique: application à l'analyse lexicale par contexte, Cahiers de l'analyse des données, Volume 8, Numéro 2, 1983. <https://www.numdam.org/item/?id=CAD_1983__8_2_187_0>
 #' - Reinert M., Alceste une méthodologie d'analyse des données textuelles et une application: Aurelia De Gerard De Nerval, Bulletin de Méthodologie Sociologique, Volume 26, Numéro 1, 1990. \doi{10.1177/075910639002600103}
 #' - Barnier J., Privé F., rainette: The Reinert Method for Textual Data Clustering, 2023, \doi{10.32614/CRAN.package.rainette}
 #'
 #' @examples
-#'
 #' \donttest{
 #' data(mobydick)
 #' res <- reinert(
-#'   x=mobydick,
+#'   x = mobydick,
 #'   k = 10,
 #'   term = "token",
 #'   segment_size = 40,
@@ -48,35 +49,36 @@ utils::globalVariables(c("doc_id","uc","uce","segment_size","upos","noSingleChar
 #'
 
 reinert <- function(
-  x, k = 10, term="token",
-  segment_size = 40,
-  min_segment_size = 3,
-  min_split_members = 5,
-  cc_test = 0.3, tsj = 3
-  ) {
-
+    x, k = 10, term = "token",
+    segment_size = 40,
+    min_segment_size = 3,
+    min_split_members = 5,
+    cc_test = 0.3, tsj = 3) {
   if (min_split_members < 3) {
     warning("min_split_members has been set to 3, its smallest possible value.")
     min_split_members <- 3
   }
 
-  uposList <- c('ADP','DET','INTJ','NUM','PART','PRON','PUNCT','SCONJ','SYM',
-    'X','EMAIL','EMOJI','HASH','IP_ADDRESS','MENTION','URL')
+  uposList <- c(
+    "ADP", "DET", "INTJ", "NUM", "PART", "PRON", "PUNCT", "SCONJ", "SYM",
+    "X", "EMAIL", "EMOJI", "HASH", "IP_ADDRESS", "MENTION", "URL"
+  )
 
   ## Create DTM from TAll Data Frame
   switch(term,
-         token={
-           x <- x %>%
-             dplyr::filter(!upos %in% uposList & noSingleChar) %>%
-             mutate(token_rainette=tolower(token))
-           colTerm <- "token_rainette"
-         },
-         lemma={
-           x <- x %>%
-             dplyr::filter(!upos %in% uposList & noSingleChar) %>%
-             mutate(lemma_rainette=tolower(lemma))
-           colTerm <- "lemma_rainette"
-         })
+    token = {
+      x <- x %>%
+        dplyr::filter(!upos %in% uposList & noSingleChar) %>%
+        mutate(token_rainette = tolower(token))
+      colTerm <- "token_rainette"
+    },
+    lemma = {
+      x <- x %>%
+        dplyr::filter(!upos %in% uposList & noSingleChar) %>%
+        mutate(lemma_rainette = tolower(lemma))
+      colTerm <- "lemma_rainette"
+    }
+  )
 
 
   ## Create segments by segment_size
@@ -90,38 +92,45 @@ reinert <- function(
   corresp_uce_uc_full$term <- x[[colTerm]]
 
   ## Table with assosacions among uc and uce
-  corresp_uce_uc <- corresp_uce_uc_full %>% select(-"doc_id", -"term") %>% distinct() %>% as.data.frame()
+  corresp_uce_uc <- corresp_uce_uc_full %>%
+    select(-"doc_id", -"term") %>%
+    distinct() %>%
+    as.data.frame()
 
   ## Table with segments
   corresp_uce_uc_full <- corresp_uce_uc_full %>%
     group_by(doc_id, uc) %>%
-    summarize(segment = paste0(term,collapse = " ")) %>%
+    summarize(segment = paste0(term, collapse = " ")) %>%
     as.data.frame()
 
   corresp_uce_uc_full <- corresp_uce_uc_full %>%
     group_by(uc) %>%
-    reframe(doc_id = doc_id[1],
-      segment = paste0(segment,collapse=" ")) %>% distinct() %>% data.frame()
+    reframe(
+      doc_id = doc_id[1],
+      segment = paste0(segment, collapse = " ")
+    ) %>%
+    distinct() %>%
+    data.frame()
 
   row.names(corresp_uce_uc_full) <- corresp_uce_uc_full$uc
 
-  dtf <- document_term_frequencies(x, document="uc",term=colTerm)
+  dtf <- document_term_frequencies(x, document = "uc", term = colTerm)
 
 
   ## Apply binary weighting
   dtf <- dtf %>%
-    mutate(freq=freq^0)
+    mutate(freq = freq^0)
 
   ## create DTM
-  dtmOriginal <- document_term_matrix(dtf, weight="freq")
+  dtmOriginal <- document_term_matrix(dtf, weight = "freq")
 
   dtmOriginal <- dtm_remove_lowfreq(dtmOriginal, minfreq = 3)
   ## Remove low frequency terms
   dtm <- as.matrix(dtmOriginal)
 
   ## Remove empty strings to avoid subcript out of bounds errors
-  ind <- rowSums(dtm)>0
-  dtm <- dtm[ind,]
+  ind <- rowSums(dtm) > 0
+  dtm <- dtm[ind, ]
 
   message("  Clustering...")
 
@@ -132,55 +141,54 @@ reinert <- function(
 
   i <- 1
 
-  while(i<k){
-      ## Split the biggest group
-      nrows <- purrr::map(res[[i]]$tabs, nrow)
-      names(nrows) <- 1:length(nrows)
-      #nrows <- lapply(nrows, function(x) if (is.null(x)) 0 else x)
-      #biggest_group <- which.max(nrows)
-      if (length(exclusion_list)>0){
-        biggest_group <- as.numeric(names(which.max(nrows[-exclusion_list])))
-      } else {
-        biggest_group <- as.numeric(names(which.max(nrows)))
-      }
-
-      if (nrow(res[[i]]$tabs[[biggest_group]]) < min_split_members) {
-        message("! No more group bigger than min_split_members. Stopping after iteration ", i, ".")
-        k <- i
-        break
-      }
-      tab <- res[[i]]$tabs[[biggest_group]]
-      ## textmodel_ca only works if nrow >= 3 and ncol >= 3
-      if (nrow(tab) < 3 || ncol(tab) < 3) {
-        message("! Tab to be splitted is not big enough. Stopping after iteration ", i, ".")
-        k <- i
-        break
-      }
-
-      ## Remove documents and features with zero occurrences
-      tab <- tab[rowSums(tab) > 0, colSums(tab) > 0]
-
-      clusters <- cluster_tab(tab, cc_test = cc_test, tsj = tsj)
-      if ("matrix" %in% class(clusters$tabs[[1]]) & "matrix" %in% class(clusters$tabs[[2]])){
-        ## Populate results
-        res[[i + 1]] <- list()
-        res[[i + 1]]$height <- clusters$height
-        res[[i + 1]]$splitted <- c(biggest_group, biggest_group + 1)
-        res[[i + 1]]$tabs <- append(res[[i]]$tabs[-biggest_group],
-                                    clusters$tabs,
-                                    after = biggest_group - 1
-        )
-        res[[i + 1]]$groups <- append(res[[i]]$groups[-biggest_group],
-                                      clusters$groups,
-                                      after = biggest_group - 1
-        )
-        i <- i + 1
-      } else {
-        exclusion_list <- c(exclusion_list, biggest_group)
-      }
-
+  while (i < k) {
+    ## Split the biggest group
+    nrows <- purrr::map(res[[i]]$tabs, nrow)
+    names(nrows) <- 1:length(nrows)
+    # nrows <- lapply(nrows, function(x) if (is.null(x)) 0 else x)
+    # biggest_group <- which.max(nrows)
+    if (length(exclusion_list) > 0) {
+      biggest_group <- as.numeric(names(which.max(nrows[-exclusion_list])))
+    } else {
+      biggest_group <- as.numeric(names(which.max(nrows)))
     }
-  #})
+
+    if (nrow(res[[i]]$tabs[[biggest_group]]) < min_split_members) {
+      message("! No more group bigger than min_split_members. Stopping after iteration ", i, ".")
+      k <- i
+      break
+    }
+    tab <- res[[i]]$tabs[[biggest_group]]
+    ## textmodel_ca only works if nrow >= 3 and ncol >= 3
+    if (nrow(tab) < 3 || ncol(tab) < 3) {
+      message("! Tab to be splitted is not big enough. Stopping after iteration ", i, ".")
+      k <- i
+      break
+    }
+
+    ## Remove documents and features with zero occurrences
+    tab <- tab[rowSums(tab) > 0, colSums(tab) > 0]
+
+    clusters <- cluster_tab(tab, cc_test = cc_test, tsj = tsj)
+    if ("matrix" %in% class(clusters$tabs[[1]]) & "matrix" %in% class(clusters$tabs[[2]])) {
+      ## Populate results
+      res[[i + 1]] <- list()
+      res[[i + 1]]$height <- clusters$height
+      res[[i + 1]]$splitted <- c(biggest_group, biggest_group + 1)
+      res[[i + 1]]$tabs <- append(res[[i]]$tabs[-biggest_group],
+        clusters$tabs,
+        after = biggest_group - 1
+      )
+      res[[i + 1]]$groups <- append(res[[i]]$groups[-biggest_group],
+        clusters$groups,
+        after = biggest_group - 1
+      )
+      i <- i + 1
+    } else {
+      exclusion_list <- c(exclusion_list, biggest_group)
+    }
+  }
+  # })
 
   if (k == 1) {
     message("! No computed clusters. Returning NULL.")
@@ -196,18 +204,18 @@ reinert <- function(
     split <- res[[i]]$splitted
     merge <- rbind(merge, -groups[split])
     groups <- groups[-split[2]]
-    groups[split[1]] <- - (k - i)
+    groups[split[1]] <- -(k - i)
   }
 
   # Compute groups by uce at each k
   uce_groups <- list()
   for (i in 1:(k - 1)) {
-    #group <- rep(NA, nrow(corresp_uce_uc))
+    # group <- rep(NA, nrow(corresp_uce_uc))
     group <- rep(NA, nrow(corresp_uce_uc_full))
     indices <- res[[i]]$groups
     for (group_index in seq_along(indices)) {
-      group[corresp_uce_uc_full[indices[[group_index]],"uc"]] <- group_index
-      #group[corresp_uce_uc_full$uc %in% as.numeric(indices[[group_index]])] <- group_index
+      group[corresp_uce_uc_full[indices[[group_index]], "uc"]] <- group_index
+      # group[corresp_uce_uc_full$uc %in% as.numeric(indices[[group_index]])] <- group_index
     }
     uce_groups[[i]] <- group
   }
@@ -230,8 +238,8 @@ reinert <- function(
     uce_groups = uce_groups,
     corresp_uce_uc = corresp_uce_uc,
     corresp_uce_uc_full = corresp_uce_uc_full,
-    dtm=dtm,
-    dtmOriginal=dtmOriginal
+    dtm = dtm,
+    dtmOriginal = dtmOriginal
   )
 
   class(hres) <- c("reinert_tall", "hclust")
@@ -239,8 +247,8 @@ reinert <- function(
 }
 
 
-order_docs <- function(m) {
 
+order_docs <- function(m) {
   ## Compute first factor of CA on DTM
   ## Code taken from getAnywhere(textmodel_ca.dfm)
   p <- m / sum(m)
@@ -259,7 +267,6 @@ order_docs <- function(m) {
 
 
 switch_docs <- function(m, indices, max_index, max_chisq) {
-
   ## Group indices and tabs
   group1 <- indices[1:which(indices == max_index)]
   group2 <- indices[(which(indices == max_index) + 1):length(indices)]
@@ -299,7 +306,6 @@ switch_docs <- function(m, indices, max_index, max_chisq) {
 
 
 select_features <- function(m, indices1, indices2, cc_test = 0.3, tsj = 3) {
-
   ## features count for each group
   tab1 <- colSums(m[indices1, , drop = FALSE])
   tab2 <- colSums(m[indices2, , drop = FALSE])
@@ -350,7 +356,6 @@ select_features <- function(m, indices1, indices2, cc_test = 0.3, tsj = 3) {
 
 
 cluster_tab <- function(m, cc_test = 0.3, tsj = 3) {
-
   uc <- row.names(m)
   ## Remove features with zero
   storage.mode(m) <- "integer"
@@ -377,8 +382,8 @@ cluster_tab <- function(m, cc_test = 0.3, tsj = 3) {
 
   return(list(
     groups = list(
-      rainette_uc_id=uc[indices1],
-      rainette_uc_id=uc[indices2]
+      rainette_uc_id = uc[indices1],
+      rainette_uc_id = uc[indices2]
     ),
     tabs = list(
       m[indices1, cols1],
@@ -406,18 +411,18 @@ split_segments <- function(doc_id, segment_size) {
     }
   }
 
-  return(data.frame(doc_id=doc_id,uce=segment_id))
+  return(data.frame(doc_id = doc_id, uce = segment_id))
 }
 
-merge_small_segments <- function(idTable, min_length=5) {
+merge_small_segments <- function(idTable, min_length = 5) {
   idTable %>%
     group_by(uce) %>%
-    mutate(segment_size = n()) %>%  # Calcola la dimensione di ogni segmento
-    #ungroup() %>%
+    mutate(segment_size = n()) %>% # Calcola la dimensione di ogni segmento
+    # ungroup() %>%
     mutate(
-      uc = if_else(segment_size < min_length, uce-1, uce)
+      uc = if_else(segment_size < min_length, uce - 1, uce)
     ) %>%
-    select(-segment_size)  # Rimuove la colonna temporanea
+    select(-segment_size) # Rimuove la colonna temporanea
 }
 
 #' Extract Terms and Segments for Document Clusters
@@ -455,11 +460,10 @@ merge_small_segments <- function(idTable, min_length=5) {
 #' and filters terms based on their significance. Terms can be excluded based on their significance (\code{signExcluded}).
 #'
 #' @examples
-#'
 #' \donttest{
 #' data(mobydick)
 #' res <- reinert(
-#'   x=mobydick,
+#'   x = mobydick,
 #'   k = 10,
 #'   term = "token",
 #'   segment_size = 40,
@@ -469,79 +473,79 @@ merge_small_segments <- function(idTable, min_length=5) {
 #'   tsj = 3
 #' )
 #'
-#' tc <- term_per_cluster(res, cutree = NULL, k=1:10, negative=FALSE)
+#' tc <- term_per_cluster(res, cutree = NULL, k = 1:10, negative = FALSE)
 #'
-#' head(tc$segments,10)
-#'
-#' head(tc$terms,10)
+#' head(tc$segments, 10)
 #'
+#' head(tc$terms, 10)
 #' }
 #'
 #' @export
 
-term_per_cluster <- function(res, cutree=NULL, k=1, negative=TRUE){
-
+term_per_cluster <- function(res, cutree = NULL, k = 1, negative = TRUE) {
   k <- k[!is.na(k)]
   dtm <- res$dtmOriginal
-  groups <- cutree_reinart(res,cutree)
+  groups <- cutree_reinart(res, cutree)
   terms <- colnames(dtm)
 
   ## integrate dtm with removed segments (by full-zero rows)
   label <- row.names(dtm)
   max_ind <- max(res$corresp_uce_uc_full$uc)
 
-  ind <- setdiff(as.character(1:max_ind),label)
+  ind <- setdiff(as.character(1:max_ind), label)
 
-  if (length(ind)>0){
-    m <- matrix(0,length(ind),ncol(dtm))
+  if (length(ind) > 0) {
+    m <- matrix(0, length(ind), ncol(dtm))
     row.names(m) <- ind
-    dtm <- rbind(dtm,m)
+    dtm <- rbind(dtm, m)
     dtm <- dtm[order(as.numeric(rownames(dtm))), ]
   }
 
   terms_list <- list()
   segments_list <- list()
   K <- k
-  for (i in 1:length(K)){
+  for (i in 1:length(K)) {
     k <- K[i]
     ## list of segments following into the cluster k
     select <- (groups == k & !is.na(groups))
     segments <- row.names(dtm)[select]
-    segments_df <- tibble(uc=as.numeric(segments)) %>%
-      left_join(res$corresp_uce_uc_full, by="uc") %>%
+    segments_df <- tibble(uc = as.numeric(segments)) %>%
+      left_join(res$corresp_uce_uc_full, by = "uc") %>%
       mutate(cluster = k)
-    segments_list[[k]] <-segments_df
+    segments_list[[k]] <- segments_df
 
     chi_res_df <- dtm_chisq(dtm, groups = select) %>%
-      mutate(indep = sum(freq_true)/sum(freq)) %>%  # expected proportion for independence
+      mutate(indep = sum(freq_true) / sum(freq)) %>% # expected proportion for independence
       mutate(cluster = k) %>%
-      rename("chi_square" = "chisq",
-        "p_value" = "p.value")
+      rename(
+        "chi_square" = "chisq",
+        "p_value" = "p.value"
+      )
 
     terms_list[[k]] <- chi_res_df
   }
 
 
-  if (isTRUE(negative)){
+  if (isTRUE(negative)) {
     signExcluded <- c("none")
-
   } else {
-    signExcluded <- c("none","negative")
+    signExcluded <- c("none", "negative")
   }
 
   terms_list <- bind_rows(terms_list) %>%
     group_by(term) %>%
     mutate(freq = sum(freq_true)) %>%
     ungroup() %>%
-    filter(p_value<=0.001) %>%
-    mutate(freq = freq_true/freq,
-           sign = ifelse(freq>indep,"positive","negative")) %>%
-      filter(!sign %in% signExcluded)
+    filter(p_value <= 0.001) %>%
+    mutate(
+      freq = freq_true / freq,
+      sign = ifelse(freq > indep, "positive", "negative")
+    ) %>%
+    filter(!sign %in% signExcluded)
 
   segments_list <- bind_rows(segments_list) %>% drop_na("doc_id")
 
-  return(list(terms =  terms_list, segments = segments_list))
-
+  return(list(terms = terms_list, segments = segments_list))
 }
 
 # plot for terms by cluster
@@ -575,7 +579,7 @@ term_per_cluster <- function(res, cutree=NULL, k=1, negative=TRUE){
 #' \dontrun{
 #' data(mobydick)
 #' res <- reinert(
-#'   x=mobydick,
+#'   x = mobydick,
 #'   k = 10,
 #'   term = "token",
 #'   segment_size = 40,
@@ -585,7 +589,7 @@ term_per_cluster <- function(res, cutree=NULL, k=1, negative=TRUE){
 #'   tsj = 3
 #' )
 #'
-#' tc <- term_per_cluster(res, cutree = NULL, k=1, negative=FALSE)
+#' tc <- term_per_cluster(res, cutree = NULL, k = 1, negative = FALSE)
 #'
 #' fig <- reinPlot(tc$terms, nPlot = 10)
 #' }
@@ -621,26 +625,31 @@ reinPlot <- function(terms, nPlot = 10) {
     x = ~chi_square,
     y = ~term,
     type = "bar",
-    orientation = 'h',
-    marker = list(color = ~ifelse(sign == "positive", color[1], color[2])),
+    orientation = "h",
+    marker = list(color = ~ ifelse(sign == "positive", color[1], color[2])),
     hovertemplate = "<b><i>Term: %{y}</i></b> <br> <b><i>Chi2: %{x}</i></b><extra></extra>"
   )
 
   # layout
-  fig1 <- fig1 %>% plotly::layout(yaxis = list(title ="Terms", showgrid = FALSE, showline = FALSE, showticklabels = TRUE, domain= c(0, 1)),
-                          xaxis = list(title = "Chi2", zeroline = FALSE, showline = FALSE, showticklabels = TRUE, showgrid = FALSE),
-                          plot_bgcolor  = "rgba(0, 0, 0, 0)",
-                          paper_bgcolor = "rgba(0, 0, 0, 0)") %>%
-    plotly::config(displaylogo = FALSE,
-           modeBarButtonsToRemove = c(
-             'sendDataToCloud',
-             'pan2d',
-             'select2d',
-             'lasso2d',
-             'toggleSpikelines',
-             'hoverClosestCartesian',
-             'hoverCompareCartesian'
-           ))
+  fig1 <- fig1 %>%
+    plotly::layout(
+      yaxis = list(title = "Terms", showgrid = FALSE, showline = FALSE, showticklabels = TRUE, domain = c(0, 1)),
+      xaxis = list(title = "Chi2", zeroline = FALSE, showline = FALSE, showticklabels = TRUE, showgrid = FALSE),
+      plot_bgcolor = "rgba(0, 0, 0, 0)",
+      paper_bgcolor = "rgba(0, 0, 0, 0)"
+    ) %>%
+    plotly::config(
+      displaylogo = FALSE,
+      modeBarButtonsToRemove = c(
+        "sendDataToCloud",
+        "pan2d",
+        "select2d",
+        "lasso2d",
+        "toggleSpikelines",
+        "hoverClosestCartesian",
+        "hoverCompareCartesian"
+      )
+    )
 
   return(fig1)
 }
@@ -680,11 +689,10 @@ reinPlot <- function(terms, nPlot = 10) {
 #' @seealso \code{\link{term_per_cluster}}, \code{\link{reinPlot}}
 #'
 #' @examples
-#'
 #' \donttest{
 #' data(mobydick)
 #' res <- reinert(
-#'   x=mobydick,
+#'   x = mobydick,
 #'   k = 10,
 #'   term = "token",
 #'   segment_size = 40,
@@ -694,51 +702,52 @@ reinPlot <- function(terms, nPlot = 10) {
 #'   tsj = 3
 #' )
 #'
-#' tc <- term_per_cluster(res, cutree = NULL, k=1:10, negative=FALSE)
+#' tc <- term_per_cluster(res, cutree = NULL, k = 1:10, negative = FALSE)
 #'
-#' S <- reinSummary(tc, n=10)
+#' S <- reinSummary(tc, n = 10)
 #'
 #' head(S, 10)
 #' }
 #'
 #' @export
 #'
-reinSummary <- function(tc, n=10){
+reinSummary <- function(tc, n = 10) {
   segments <- tc$segments %>%
     group_by(cluster) %>%
     # summarise("Number of Segments" = n()) %>%
     # group_by(cluster) %>%
-    summarize("Most frequent document" = names(which.max(table(doc_id))),
-              "N. of Segments per Cluster" = n()
+    summarize(
+      "Most frequent document" = names(which.max(table(doc_id))),
+      "N. of Segments per Cluster" = n()
     )
 
-    terms <- tc$terms %>%
-      group_by(cluster, sign) %>%
-      slice_max(order_by = chi_square, n = 10, with_ties = TRUE) %>%
-      summarize(terms = paste0(term, collapse = "; "), .groups = "drop") %>%
-      pivot_wider(
-        names_from = sign,
-        values_from = terms,
-        names_prefix = "",
-        values_fill = list(terms = NA) # Riempie con NA se mancano valori
-      )
+  terms <- tc$terms %>%
+    group_by(cluster, sign) %>%
+    slice_max(order_by = chi_square, n = 10, with_ties = TRUE) %>%
+    summarize(terms = paste0(term, collapse = "; "), .groups = "drop") %>%
+    pivot_wider(
+      names_from = sign,
+      values_from = terms,
+      names_prefix = "",
+      values_fill = list(terms = NA) # Riempie con NA se mancano valori
+    )
 
-    if (!"positive" %in% names(terms)){
-      terms$positive <- ""
-    } else {
-      terms$positive[is.na(terms$positive)] <- ""
-    }
-    if (!"negative" %in% names(terms)){
-      terms$negative <- ""
-    } else {
-      terms$negative[is.na(terms$negative)] <- ""
-    }
+  if (!"positive" %in% names(terms)) {
+    terms$positive <- ""
+  } else {
+    terms$positive[is.na(terms$positive)] <- ""
+  }
+  if (!"negative" %in% names(terms)) {
+    terms$negative <- ""
+  } else {
+    terms$negative[is.na(terms$negative)] <- ""
+  }
 
-      terms <- terms %>%
-      rename(
-        "Positively Associated Terms" = positive,
-        "Negatively Associated Terms" = negative
-      )
+  terms <- terms %>%
+    rename(
+      "Positively Associated Terms" = positive,
+      "Negatively Associated Terms" = negative
+    )
 
 
   summaryTable <- terms %>%
@@ -748,17 +757,18 @@ reinSummary <- function(tc, n=10){
 }
 
 cutree_reinart <- function(res, k = NULL) {
-  if (!is.null(k)){
-    res$uce_groups[[min(c(k-1,length(res$uce_groups)))]]
-  } else{
+  if (!is.null(k)) {
+    res$uce_groups[[min(c(k - 1, length(res$uce_groups)))]]
+  } else {
     res$uce_groups[[length(res$uce_groups)]]
   }
-
 }
 
 ## Color palette for plots
-colorlist <- function(){
-  c("#4DAF4A", "#E41A1C","#377EB8","#984EA3","#FF7F00","#A65628","#F781BF","#999999","#66C2A5","#FC8D62","#8DA0CB","#E78AC3","#A6D854","#FFD92F"
-    ,"#B3B3B3","#A6CEE3","#1F78B4","#B2DF8A","#33A02C","#FB9A99","#E31A1C","#FDBF6F","#FF7F00","#CAB2D6","#6A3D9A","#B15928","#8DD3C7","#BEBADA"
-    ,"#FB8072","#80B1D3","#FDB462","#B3DE69","#D9D9D9","#BC80BD","#CCEBC5")
+colorlist <- function() {
+  c(
+    "#4DAF4A", "#E41A1C", "#377EB8", "#984EA3", "#FF7F00", "#A65628", "#F781BF", "#999999", "#66C2A5", "#FC8D62", "#8DA0CB", "#E78AC3", "#A6D854", "#FFD92F",
+    "#B3B3B3", "#A6CEE3", "#1F78B4", "#B2DF8A", "#33A02C", "#FB9A99", "#E31A1C", "#FDBF6F", "#FF7F00", "#CAB2D6", "#6A3D9A", "#B15928", "#8DD3C7", "#BEBADA",
+    "#FB8072", "#80B1D3", "#FDB462", "#B3DE69", "#D9D9D9", "#BC80BD", "#CCEBC5"
+  )
 }
